<?php /*
* theme extra functions 
*/
/* inner banner */
function astn_inner_banner() { ?>
    <div class="inner-banner d-flex flex-column justify-content-center align-items-center"
         style="background:url( <?php if ( get_theme_mod( 'inner_header_image' ) ) {
		     echo esc_url( get_theme_mod( 'inner_header_image' ) );
	     } else {
		     echo esc_url( get_template_directory_uri() ) . "/images/inner.jpg";
	     } ?>);"></div>
<?php }
add_action( 'astn_top_banner', 'astn_inner_banner' );

/* display comments */
if ( ! function_exists( 'astn_comment' ) ) :
	function astn_comment( $comment, $args, $depth ) {
		//get theme data
		global $comment_data;
		//translations
		$leave_reply = $comment_data['translation_reply_to_coment'] ? $comment_data['translation_reply_to_coment'] :
			__( 'Reply', 'astn' ); ?>
        <div class="comments">
            <div class="comments-grids">
                <div class="media">
					<?php echo get_avatar( $comment, $size = '60' ); ?>
                    <div class="media-body comments-grid-right">
                        <h4><?php comment_author(); ?></h4>

                        <ul class="my-2">
                            <li class="font-weight-bold"><?php comment_date(); ?>
								<?php esc_html_e( 'at', 'astn' ); ?>&nbsp;<?php comment_time( 'g:i a' ); ?></li>
                        </ul>

						<?php comment_text(); ?>

                        <div class="reply">
							<?php comment_reply_link( array_merge( $args, array(
								'reply_text' => $leave_reply,
								'depth'      => $depth,
								'max_depth'  => $args['max_depth']
							) ) ) ?>
                        </div>

						<?php if ( $comment->comment_approved == '0' ) : ?>
                            <em class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'astn' ); ?></em>
                            <br/>
						<?php endif; ?>
                    </div>
                </div>
            </div>
        </div>
	<?php }
endif;

/* breadcrumb */
if ( ! function_exists( 'astn_breadcrumb' ) ) :
	function astn_breadcrumb() { ?>
        <nav aria-label="breadcrumb">
			<?php if ( have_posts() ) { ?>
                <ol class="breadcrumb d-flex justify-content-center">
                    <li class="breadcrumb-item">
                        <a href="<?php echo esc_url( home_url() ); ?>"><?php esc_html_e( 'Home', 'astn' ); ?></a>
                    </li>

					<?php if ( is_page() || is_single() ) { ?>
                        <li class="breadcrumb-item " aria-current="page"><?php the_title(); ?></li> <?php } ?>

					<?php if ( is_category() || is_tag() ) { ?>
                        <li class="breadcrumb-item " aria-current="page"><?php echo single_cat_title(); ?></li>
					<?php } ?>

					<?php if ( is_archive() && ! is_tag() && ! is_author() ) { ?>
                        <li class="breadcrumb-item " aria-current="page">
							<?php if ( is_day() ) :
								/* translators: %s: date. */
								printf( esc_html__( 'Daily Archives: %s', 'astn' ), '<span>' . get_the_date() . '</span>' );
                            elseif ( is_month() ) :
								/* translators: %s: month. */
								printf( esc_html__( 'Monthly Archives: %s', 'astn' ), '<span>' . get_the_date( _x( 'F Y', 'monthly archives date format', 'astn' ) ) . '</span>' );
                            elseif ( is_year() ) :
								/* translators: %s: year. */
								printf( esc_html__( 'Yearly Archives: %s', 'astn' ), '<span>' . get_the_date( _x( 'Y', 'yearly archives date format', 'astn' ) ) . '</span>' );
							else :
								//esc_html_e( 'Archives', 'astn' );
							endif; ?>
                        </li>
					<?php } ?>

					<?php if ( is_search() ) {
						/* translators: %s: search term. */ ?>
                        <li class="breadcrumb-item "
                            aria-current="page"><?php printf( esc_html__( 'Search Results for: %s', 'astn' ), '<span>' . get_search_query() . '</span>' ); ?></li>
					<?php } ?>

					<?php if ( is_author() ) { ?>
                        <li class="breadcrumb-item active" aria-current="page"><?php echo get_the_author(); ?></li>
					<?php } ?>

                </ol>
			<?php } elseif ( is_404() ) { ?>

                <ol class="breadcrumb d-flex justify-content-center">
                    <li class="breadcrumb-item">
                        <a href="<?php echo esc_url( home_url() ); ?>"><?php esc_html_e( 'Home', 'astn' ); ?></a>
                    </li>

                    <li class="breadcrumb-item"><?php esc_html_e( '404 Error', 'astn' ); ?></li>
                </ol>
			<?php } ?>
        </nav>
		<?php
	}
endif;
add_action( 'astn_breadcrumb_area', 'astn_breadcrumb' );

/* single post navigation */
function astn_post_navigation() { ?>
    <div class="navigation">
        <div class="single_left alignleft">
			<?php previous_post_link(); ?>
        </div>
        <div class="single_right alignright">
			<?php next_post_link(); ?>
        </div>
    </div>
	<?php
}
add_action( 'astn_single_blog_navigation', 'astn_post_navigation' );

/* pagination link for index, author, category, tag pages */
function astn_navigation() { ?>
    <div class="navigation">
		<?php posts_nav_link(); ?>
    </div>
	<?php
}
add_action( 'astn_pagination', 'astn_navigation' );

/* excerpt length */
function astn_excerpt_length( $length ) {
	return 30;
}
add_filter( 'excerpt_length', 'astn_excerpt_length' );

/* wp_body_open function check */
if ( ! function_exists( 'wp_body_open' ) ) {
    function wp_body_open() {
        do_action( 'wp_body_open' );
    }
}

/**
 * Register and enqueue a custom stylesheet in the WordPress admin.
 */
function astn_enqueue_custom_admin_style() {
        wp_register_style( 'astn_custom_admin_css', get_template_directory_uri() . '/css/admin-themes.css' );
        wp_enqueue_style( 'astn_custom_admin_css' );
}
add_action( 'admin_enqueue_scripts', 'astn_enqueue_custom_admin_style' );